/*
** 1998-08-15 -	Header for the icon utility module.
*/

#if !defined ICONUTIL_H
#define	ICONUTIL_H

typedef struct IconInfo	IconInfo;

IconInfo *	ico_initialize(MainInfo *min);

GList *		ico_get_all(MainInfo *min, const gchar *path);
gboolean	ico_no_icon(const gchar *name);
void		ico_free_all(GList *list);

GdkPixmap *	ico_icon_get(MainInfo *min, const gchar *name, GdkBitmap **mask);

void		ico_flush(MainInfo *min);

#endif		/* ICONUTIL_H */
